pub enum CompletionFinishReason {
Eos,
MatchingStoppingSequence(StoppingSequence),
NonMatchingStoppingSequence(Option<String>),
StopLimit,
ToolsCall,
}Variants
Eos
The completion finished because the model generated the EOS token.
MatchingStoppingSequence(StoppingSequence)
The completion finished because the model generated a stop sequence that matches one of the provided stop sequences.
NonMatchingStoppingSequence(Option<String>)
The completion finished because the model generated a stop sequence that does not match any of the provided stop sequences.
StopLimit
The completion finished because the model reached the maximum token limit.
ToolsCall
The completion finished because the model use the tool